==> portal-transparencia-2.024.0.zip: BOOT-INF/classes/db/sql/contab/veiculo.sql <==
 SELECT V.BEM AS VEICULO,
        V.CHAPA,
        V.CHASSI,
        V.DESCRICAO,
        V.RENAVAN,
        CC.DESCRICAO AS CENTROCUSTO,
        V.DATAAQUISICAO,
        V.LETRAPLACA || V.NUMEROPLACA AS PLACA,
        PA.DESCRICAO AS TIPOINCORPORACAO,
        B.CLASSIFICACAO AS IDCLASSIFICACAO,
        B.DESCRICAO AS CLASSIFICACAO,
        C.IDTIPOMEDIDOR,
        D.DSTIPOMEDIDOR,
        A.PLAQUETAANT AS NUMEROFROTA,
        V.BAIXADO,
        A.VALORAQUISICAO,
        A.NOTAFISCAL, t.DESCRICAO AS COMBUSTIVELDESCRICAO
   FROM ${db.contabilidade.schema}.PAT_BEM A
   LEFT OUTER JOIN ${db.contabilidade.schema}.PAT_CATEGORIACLASSIFICACAO B
     ON B.CLASSIFICACAO = A.CATEGORIA
   LEFT JOIN ${db.contabilidade.schema}.PAT_TIPOAGRUPAMENTOBEM C
     ON B.IDTIPOAGRUPAMENTOBEM = C.ID
   LEFT JOIN ${db.contabilidade.schema}.PAT_TIPOMEDIDOR D
     ON C.IDTIPOMEDIDOR = D.ID
  INNER JOIN ${db.contabilidade.schema}.PAT_VEICULO V
     ON V.ENTIDADE = A.ENTIDADE
    AND V.TIPO = A.TIPO
    AND V.BEM = A.BEM
    AND V.CHAPA = A.CHAPA
   LEFT OUTER JOIN ${db.contabilidade.schema}.EST_CENTROCUSTO CC
     ON CC.CENTROCUSTO = V.CENTROCUSTO
    AND CC.ENTIDADE = V.ENTIDADE
   LEFT OUTER JOIN ${db.contabilidade.schema}.PAT_ALIENACAO PA
     ON A.INCORPORACAO = PA.ALIENACAO
   LEFT JOIN ${db.contabilidade.schema}.PAT_TIPOCOMBUSTIVEL t
     on v.tipocombustivel = t.tipocombustivel	 
  WHERE (V.ENTIDADE = :entidade or A.COMPARTILHA_ENTSN = 'S')
    AND V.BEM = :veiculo
    AND V.CHAPA = :chapa
    AND V.TIPO = 'V'

==> portal-transparencia-3.50.0.zip: BOOT-INF/classes/db/sql/contab/veiculo.sql <==
 SELECT V.BEM AS VEICULO,
        V.CHAPA,
        V.CHASSI,
        V.DESCRICAO,
        V.RENAVAN,
        CC.DESCRICAO AS CENTROCUSTO,
        V.DATAAQUISICAO,
        V.LETRAPLACA || V.NUMEROPLACA AS PLACA,
        PA.DESCRICAO AS TIPOINCORPORACAO,
        B.CLASSIFICACAO AS IDCLASSIFICACAO,
        B.DESCRICAO AS CLASSIFICACAO,
        C.IDTIPOMEDIDOR,
        D.DSTIPOMEDIDOR,
        A.PLAQUETAANT AS NUMEROFROTA,
        V.BAIXADO,
        A.VALORAQUISICAO,
        A.NOTAFISCAL, t.DESCRICAO AS COMBUSTIVELDESCRICAO,
        EC.DESCRICAO AS ESTADOCONSERVACAO
   FROM ${db.contabilidade.schema}.PAT_BEM A
   LEFT OUTER JOIN ${db.contabilidade.schema}.PAT_CATEGORIACLASSIFICACAO B
     ON B.CLASSIFICACAO = A.CATEGORIA
   LEFT JOIN ${db.contabilidade.schema}.PAT_TIPOAGRUPAMENTOBEM C
     ON B.IDTIPOAGRUPAMENTOBEM = C.ID
   LEFT JOIN ${db.contabilidade.schema}.PAT_TIPOMEDIDOR D
     ON C.IDTIPOMEDIDOR = D.ID
  INNER JOIN ${db.contabilidade.schema}.PAT_VEICULO V
     ON V.ENTIDADE = A.ENTIDADE
    AND V.TIPO = A.TIPO
    AND V.BEM = A.BEM
    AND V.CHAPA = A.CHAPA
   LEFT OUTER JOIN ${db.contabilidade.schema}.EST_CENTROCUSTO CC
     ON CC.CENTROCUSTO = V.CENTROCUSTO
    AND CC.ENTIDADE = V.ENTIDADE
   LEFT OUTER JOIN ${db.contabilidade.schema}.PAT_ALIENACAO PA
     ON A.INCORPORACAO = PA.ALIENACAO
   LEFT JOIN ${db.contabilidade.schema}.PAT_TIPOCOMBUSTIVEL t
     on v.tipocombustivel = t.tipocombustivel
   LEFT JOIN ${db.contabilidade.schema}.PAT_ESTADOCONSERVACAO EC
        ON EC.ESTADOCONSERVACAO = V.ESTADOCONSERVACAO AND EC.ENTIDADE = V.ENTIDADE
   WHERE (V.ENTIDADE = :entidade or A.COMPARTILHA_ENTSN = 'S')
    AND V.BEM = :veiculo
    AND V.CHAPA = :chapa
    AND V.TIPO = 'V'
